@@ -41,8 +41,6 @@
 
 #define KEMOTICONS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KEMOTICONS_NO_DEPRECATED) && !defined(KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KEMOTICONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KEMOTICONS_NO_DEPRECATED
-#  define KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef KEMOTICONS_NO_DEPRECATED_WARNINGS
 #  define KEMOTICONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KEMOTICONS_DEPRECATED_WARNINGS_SINCE KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KEMOTICONS_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KEMOTICONS_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KEMOTICONS_DEPRECATED
-#  define KEMOTICONS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KEMOTICONS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KEMOTICONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KEMOTICONS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
